#!/usr/bin/env python
# -*- coding: UTF-8 -*-

"""Module for PoA Exceptions"""

##############################################################################
#    Copyright (C) 2012-2013 by Javier Peña Blazquez <javipenya@gmail.com>
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
#
##############################################################################

##############################################################################
# @author: Javier Peña Blázquez
# @copyright: 2012-2013 Javier Peña Blazquez
# @license: http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
# @contact: <javipenya@gmail.com>
# @version: 0.1
##############################################################################

class EasyPyPoAError(Exception):
    """Base class for exceptions in EasyPyPoA module.
    
    Attributes:
        message -- explanation of the error
        error -- detailed exception description 
    """
    
    def __init__(self, message, error=""):
        self.message = message
        self.error = error
        
class ConfigurationError(EasyPyPoAError):
    """Exception raised for errors in EasyPyPoA configuration file"""

    def __str__(self):
        return "Configuration Error: " + str(self.message) + "\n" 
        + str(self.error) 
    
class PoAError(EasyPyPoAError):
    """Exception raised for errors in EasyPyPoA execution"""
    
    def __str__(self):
        return "PoA Error: " + str(self.message) + "\n" + str(self.error) 

class CryptError(EasyPyPoAError):
    """Exception raised for errors in Crypt module"""
        
    def __str__(self):
        return "Crypt Error: " + str(self.message) + "\n" + str(self.error)
    
class SessionError(EasyPyPoAError):
    """Exception raised for errors in Session module"""
        
    def __str__(self):
        return "Session Error: " + str(self.message) + "\n" + str(self.error)
    

    