#!/usr/bin/env python
# -*- coding: UTF-8 -*-

"""Module for management HTTP 302 redirects"""

##############################################################################
#    Copyright (C) 2012-2013 by Javier Peña Blazquez <javipenya@gmail.com>
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
#
##############################################################################

##############################################################################
# @author: Javier Peña Blázquez
# @copyright: 2012-2013 Javier Peña Blazquez
# @license: http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
# @contact: <javipenya@gmail.com>
# @version: 0.1
##############################################################################

import re
import sys
import urlparse
import urllib
from EasyPyPoAError import PoAError

class HTTPManager(object):
    """It is responsible for generating a correct URL, contemplating the 
    needs of coding parameters in URL format. It also performs the HTTP 302 
    redirects used by PAPI protocol by injecting the header Location."""
    
    def __init__(self, url):
        if not self._is_valid_URL(url):
            message = ("Unable create object HTTPManager, the URL received "
                       "is malformed.\nURL: " + url)
            raise PoAError(message)
        parsed_url = urlparse.urlsplit(url)
        self._scheme = parsed_url.scheme
        self._host = parsed_url.netloc
        self._abs_path = parsed_url.path
        self._query = parsed_url.query
        self._fragment = parsed_url.fragment
        
    def add_parameter(self, paramName, paramValue):
        if self._query == '':
            self._query = paramName + '=' + urllib.quote(paramValue)
        else:
            self._query += '&' + paramName + '=' + urllib.quote(paramValue)
            
    def clean_parameters(self):
        self._query = ''
        
    def HTTP_redirect(self, session=None):
        url = urlparse.urlunsplit((self._scheme, self._host, self._abs_path, 
                                   self._query, self._fragment))
        if session:
            print session.output()
        print 'Location: ' + url + '\n'
        sys.exit()
    
    def __str__(self):
        return urlparse.urlunsplit((self._scheme, self._host, self._abs_path, 
                                   self._query, self._fragment))
        
    def _is_valid_URL(self, url):
        regex = re.compile(
            r'^https?://'  # http:// or https://
            r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'  # domain...
            r'localhost|'  # localhost...
            r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}|'  # ...or ipv4
            r'\[?[A-F0-9]*:[A-F0-9:]+\]?)'  # ...or ipv6
            r'(?::\d+)?'  # optional port
            r'(?:/?|[/?]\S+)$', re.IGNORECASE)
        return url is not None and regex.search(url)
    
    
    
